@@ -1,7 +1,7 @@
 package Complete::File;
 
-our $DATE = '2015-09-20'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2015-11-06'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,6 +13,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                        complete_file
+                       complete_dir
                );
 
 our %SPEC;
@@ -193,6 +194,16 @@ sub complete_file {
         };
     }
 
+    if ($args{_dir}) {
+        my $orig_filter = $filter;
+        $filter = sub {
+            my $name = shift;
+            return 0 if $orig_filter && !$orig_filter->($name);
+            return 0 unless (-d $name);
+            1;
+        };
+    }
+
     Complete::Path::complete_path(
         word => $word,
 
@@ -210,6 +221,21 @@ sub complete_file {
     );
 }
 
+$SPEC{complete_dir} = do {
+    my $spec = {%{ $SPEC{complete_file} }}; # shallow copy
+
+    $spec->{summary} = 'Complete directory from local filesystem '.
+        '(wrapper for complete_dir() that only picks directories)';
+    delete $spec->{args}{file_regex_filter};
+
+    $spec;
+};
+sub complete_dir {
+    my %args = @_;
+
+    complete_file(%args, _dir=>1);
+}
+
 1;
 # ABSTRACT: Completion routines related to files
 
@@ -225,16 +251,18 @@ Complete::File - Completion routines related to files
 
 =head1 VERSION
 
-This document describes version 0.37 of Complete::File (from Perl distribution Complete-File), released on 2015-09-20.
+This document describes version 0.38 of Complete::File (from Perl distribution Complete-File), released on 2015-11-06.
 
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
 
 
-=head2 complete_file(%args) -> array
+=head2 complete_dir(%args) -> array
 
-Complete file and directory from local filesystem.
+Complete directory from local filesystem (wrapper for complete_dir() that only picks directories).
+
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -255,13 +283,64 @@ Case-insensitive matching.
 
 =item * B<exp_im_path> => I<bool>
 
-=item * B<file_regex_filter> => I<re>
+=item * B<filter> => I<str|code>
 
-Filter shortcut for file regex.
+Only return items matching this filter.
 
-This is a shortcut for constructing a filter. So instead of using C<filter>, you
-use this option. This will construct a filter of including only directories or
-regular files, and the file must match a regex pattern. This use-case is common.
+Filter can either be a string or a code.
+
+For string filter, you can specify a pipe-separated groups of sequences of these
+characters: f, d, r, w, x. Dash can appear anywhere in the sequence to mean
+not/negate. An example: C<f> means to only show regular files, C<-f> means only
+show non-regular files, C<drwx> means to show only directories which are
+readable, writable, and executable (cd-able). C<wf|wd> means writable regular
+files or writable directories.
+
+For code filter, you supply a coderef. The coderef will be called for each item
+with these arguments: C<$name>. It should return true if it wants the item to be
+included.
+
+=item * B<fuzzy> => I<int>
+
+Fuzzy matching.
+
+=item * B<handle_tilde> => I<bool> (default: 1)
+
+=item * B<map_case> => I<bool>
+
+=item * B<starting_path> => I<str> (default: ".")
+
+=item * B<word>* => I<str> (default: "")
+
+=back
+
+Return value:  (array)
+
+
+=head2 complete_file(%args) -> array
+
+Complete file and directory from local filesystem.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<allow_dot> => I<bool> (default: 1)
+
+If turned off, will not allow "." or ".." in path.
+
+This is most useful when combined with C<starting_path> option to prevent user
+going up/outside the starting path.
+
+=item * B<ci> => I<bool>
+
+Case-insensitive matching.
+
+=item * B<dig_leaf> => I<bool>
+
+=item * B<exp_im_path> => I<bool>
 
 =item * B<filter> => I<str|code>
 
